host_bindgen

Macro host_bindgen 

host_bindgen!() { /* proc-macro */ }
Create host bindings for the wasm component type in the file passed in (or $WIT_WORLD, if nothing is passed in). This will produce all relevant types and trait implementations for the component type, as well as functions allowing the component to be instantiated inside a sandbox.

This includes both a primitive register_host_functions, which can be used to directly register the host functions on any sandbox (and which can easily be used with Hyperlight-Wasm), as well as an instantiate() method on the component trait that makes instantiating the sandbox particularly ergonomic in core Hyperlight.