guest_bindgen!() { /* proc-macro */ }Expand description
Create the hyperlight_guest_init() function (which should be
called in hyperlight_main()) for the wasm component type in the
file passed in (or $WIT_WORLD, if nothing is passed in). This
function registers Hyperlight functions for component exports
(which are implemented by calling into the trait provided) and
implements the relevant traits for a trivial Host type (by calling
into the Hyperlight host).